@@ -200,10 +200,10 @@ class Git(Base):
             self.repo.index.add(paths)
         except AssertionError:
             msg = (
-                "failed to add '{}' to git. You can add those files"
-                " manually using 'git add'."
-                " See 'https://github.com/iterative/dvc/issues/610'"
-                " for more details.".format(str(paths))
+                "failed to add '{}' to git. You can add those files "
+                "manually using `git add`. See "
+                "https://github.com/iterative/dvc/issues/610 for more "
+                "details.".format(str(paths))
             )
 
             logger.exception(msg)
